from setuptools import setup

setup(name='fort-probability',
      version='1.1',
      description='Gaussian and binomial distributions',
      packages=['fort-probability'],
      author = 'Fortune Adekogbe',
      author_email = 'fortuneadekogbe@gmail.com',
      zip_safe=False)

